@@ -14,16 +14,25 @@ or
 
  use PDF::Extract;
  $pdf = new PDF::Extract( PDFDoc=>'C:/my.pdf' );
- $pdf->getPDFExtract( PDFPages=>@PDFPages );
+ $pdf->getPDFExtract( PDFPages=>$PDFPages );
  print "Content-Type text/plain\n\n<xmp>",  $pdf->getVars("PDFExtract");
  print $pdf->getVars("PDFError");
+ 
+ or 
+ 
+ # Extract and save, in the current directory,  all the pages in a pdf document
+use PDF::Extract;
+$pdf=new PDF::Extract( PDFDoc=>"test.pdf");
+$i=1;
+$i++ while ( $pdf->savePDFExtract( PDFPages=>$i ) );
+
 
 =head1 DESCRIPTION
 
 PDF Extract is a group of methods that allow the user to quickly grab pages
 as a new PDF document from a pre-existing PDF document.
 
- With PDF::Extract a new PDF document can be:-
+With PDF::Extract a new PDF document can be:-
 
 =over 4
 
@@ -76,12 +85,14 @@ setVars is an alias of setPDFExtractVariables
 use strict;
 #use warnings;
 use vars qw($VERSION);
-$VERSION = '2.02';
+$VERSION = '2.04';
 
 my ( $pages, $filename, $CatalogPages, $Root, $pdf, $pdfFile, $object, $encryptedPdf, $trailerObject,$fileNumber );
-my ( @object, @PDFPages, @obj, @instnum, @pages ); 
+my ( @object, @obj, @instnum, @pages ); 
 my ( %vars, %getPages, %pageObject );
 
+$vars{"PDFCache"}="."; # defaults to this directory
+
 my $CRLF = '[ \t\r\n\f\0]'."*(?:\015|\012|(?:\015\012))";
 
 # ----------------------------------------------------------- The Public Methods --------------------------------------------------------------
@@ -105,7 +116,7 @@ sub new {
     my $class = ref($this) || $this;
     my $self = {};
     bless $self, $class;
-    $self->getPDFExtract( @_) if @_;
+    $self->getPDFExtract(@_) if @_;
     return $self;
 }
 
@@ -114,16 +125,17 @@ sub new {
 This method is the main workhorse of the package. It does all the PDF processing
 and sets PDFError if its unable to create a new PDF document. It requires
 PDFDoc and PDFPages to be set either in this call of before to function. 
-It outputs a PDF document as a string or a "0" if there is an error.
+It outputs a PDF document as a string or undef if there is an error.
 
 To create an array of PDF documents, each consisting of a single page, 
 from a multi page PDF document.
 
  $pdf = new PDF::Extract( PDFDoc=>'C:/my.pdf' );
- while ( $pdf[$i]=$pdf->getPDFExtract( PDFPages=>++$i ) );
+ $i=1;
+ while ( $pdf[$i++]=$pdf->getPDFExtract( PDFPages=>$i ) );
 
-The lowest valid page number for PDFPages is 1. A value of 0 will produce no 
-output and raise an error. An error will be raised if the PDFPages value does
+The lowest valid page number for PDFPages is 1. A value of undef will produce no 
+output and raise an error. An error will be raised if the PDFPages values do
 not correspond to any pages.
 
 =cut
@@ -131,16 +143,18 @@ not correspond to any pages.
 sub getPDFExtract{                   
 	&setEnv(@_);    
 	&getDoc;
-    $vars{"PDFExtract"} ? $vars{"PDFExtract"} : 0;
+    $vars{"PDFExtract"} ? $vars{"PDFExtract"} : undef;
 }
 
 =head2  savePDFExtract
 
-This method saves its output to the directory defined for PDFCache. 
-The new PDF's filename will be an amalgam of the original filename, the requested page numbers separated with an 
-underscore "_" for individual pages,  ".." for a range of pages and the .pdf file type suffix.
+This method saves its output to the directory defined for PDFCache.  (see PDFCache)
+If PDFSaveAs is unset the new PDF's filename will be an amalgam of the original filename, the 
+requested page numbers and the .pdf file type suffix. If more than one page is extracted into a new PDF 
+the page numbers will be separated with an underscore "_" for individual pages,  ".." for a range of pages.
+eg. my6.pdf for a single page (page 6) and my1_3..6.pdf  for a multi page PDF (pages 1, 3, 4, 5, 6)
 
- $pdf->savePDFExtract(PDFPages=>"1 3-5", PDFDoc=>'C:/my.pdf', PDFCache=>"C:/myCache" );
+ $pdf->savePDFExtract(PDFPages=>"1 3-6", PDFDoc=>'C:/my.pdf', PDFCache=>"C:/myCache" );
 
 If there is an error then an error page will be served and savePDFExtract will return a "0". 
 Otherwise savePDFExtract will return "1" and the saved PDF location and file name will be "C:/myCache/my1_3..5.pdf".
@@ -180,8 +194,10 @@ sub servePDFExtract{
 
 This method serves its output to STDOUT with the correct header for a PDF document served on the web. 
 
-This method checks to see if the PDF document requested is in the cache folder, as set with PDFCache.
-The file in the cache folder is served if it exists. Otherwise a new PDF document is created, cached and served.
+If PDFSaveAs is unset the new PDF's filename will be an amalgam of the original filename, the 
+requested page numbers and the .pdf file type suffix. If more than one page is extracted into a new PDF 
+the page numbers will be separated with an underscore "_" for individual pages,  ".." for a range of pages.
+eg. my6.pdf for a single page (page 6) and my1_3..6.pdf  for a multi page PDF (pages 1, 3, 4, 5, 6).
 If there is an error then an error page will be served and fastServePDFExtract will return "0".
 fastServePDFExtract will return "1" on success.
  
@@ -199,7 +215,7 @@ fastServePDFExtract will return "1" on success.
 
 sub fastServePDFExtract{
 	&setEnv(@_);    
-	&redirect if -e "$vars{\"PDFCache\"}/$filename.pdf";
+	&redirect if -e "$vars{\"PDFCache\"}/$vars{\"PDFFilename\"} ";
 	&getDoc;
 	&savePdfDoc;
 	&redirect;
@@ -290,23 +306,46 @@ PDFDoc will be an empty string if there was an error.
 =head2 PDFPages
 (set and get)
  
- $pages=$pdf->setVars("PDFPages"=>"1 18-23");
+ $pages=$pdf->setVars( PDFPages =>"1 18-23");
  or
  $pages=$pdf->getVars("PDFPages");
 
 This variable contains a list of pages to extract from the original PDF document accessed by 
-getPDFExtract, savePDFExtract, servePDFExtract and fastServePDFExtract.
+getPDFExtract, savePDFExtract, servePDFExtract and fastServePDFExtract. 
+Use the join function to create a list of pages from an array. 
+Such a an array of pages sent from a multi select box on a web form.
+
+ PDFPages => join( " ", $cgi->param( "PDFPages" )),
 
 =head2 PDFCache
 (set and get)
 
- $cachePath=$pdf->setVars("PDFCache"=>"C:/myCache");
+ $cachePath=$pdf->setVars( PDFCache =>"C:/myCache");
  or
  $cachePath=$pdf->getVars("PDFCache");
 
-This variable contains the path to the PDF document cache. This value is required by 
-savePDFExtract and fastServePDFExtract method calls.
+This variable, if set, should contain the FULL PATH to the PDF document cache. 
+This value is used by savePDFExtract and fastServePDFExtract method calls.
 PDFCache will be an empty string if there was an error in setting the value.
+If PDFCache path does not exist an attempt will be made to create it recursively. 
+Any directories that need to be created will be created with permissions of 0x777.
+PDFCache defaults to ".", the current directory.
+
+=head2 PDFSaveAs
+(set and get)
+
+ $filename=$pdf->setVars( PDFSaveAs =>"myFileName");
+ or
+ $filename=$pdf->getVars("PDFSaveAs");
+ 
+If PDFSaveAs is unset the new PDF's filename will be an amalgam of the original filename, the 
+requested page numbers and the .pdf file type suffix. If more than one page is extracted into a new PDF 
+the page numbers will be separated with an underscore "_" for individual pages,  ".." for a range of pages.
+eg. my6.pdf for a single page (page 6) and my1_3..6.pdf  for a multi page PDF (pages 1, 3, 4, 5, 6)
+
+Setting PDFSaveAs to something other than "" or 0 will cause the output to be named with the content of PDFSaveAs.
+The .pdf filename extension and any path informationwill be stripped from the variable if set.
+PDFFilename will contain the actual filename used for the last extracted pdf'.
 
 =head2 PDFErrorPage
 (set and get)
@@ -337,7 +376,8 @@ PDFExtract will be an empty string if there was an error.
 (get only)
  
  $pagesFound=$pdf->getVars("PDFPagesFound");
- 
+ or
+ @pages = split ", ", $pdf->getVars("PDFPagesFound");
 
 This variable contains a comma seperated list of the page numbers that were selected and found within the original PDF document.
 PDFPagesFound will be a undefined if there was an error in finding any pages.
@@ -347,9 +387,27 @@ PDFPagesFound will be a undefined if there was an error in finding any pages.
  
  $pageCount=$pdf->getVars("PDFPageCount");
 
+
 This variable contains the number of the pages that were selected and found within the original PDF document.
 PDFPageCount will be an empty string if there was an error in finding any pages.
 
+=head2 PDFFileName
+(get only)
+
+ $filename=$pdf->getVars("PDFFilename");
+ 
+This variable will contain the actual filename.
+If PDFSaveAs is unset the new PDF's filename will be an amalgam of the original filename, the 
+requested page numbers and the .pdf file type suffix. If more than one page is extracted into a new PDF 
+the page numbers will be separated with an underscore "_" for individual pages,  ".." for a range of pages.
+eg. my6.pdf for a single page (page 6) and my1_3..6.pdf  for a multi page PDF (pages 1, 3, 4, 5, 6).
+If PDFSaveAs is set then PDFSaveAs will be used to construct PDFFilename.
+The full path to the extracted pdf file can be obtained by - 
+
+ $fullpath = $pdf->getVars("PDFCache") ."/". $pdf->getVars("PDFFilename");
+ or
+ ($path,$filename) = $pdf->getVars("PDFCache","PDFFilename");
+    
 =head2 PDFError
 (get only)
 
@@ -359,6 +417,31 @@ This variable contains a string describing the errors if any in processing the o
 PDFError is guarenteed to be set if  getPDFExtract, savePDFExtract, servePDFExtract or fastServePDFExtract fail and return a "0".
 PDFError will be an empty string if there was no error.
 
+=head2 PDFDebug
+(set for method call duration only)
+
+ $pdf->setVars(
+            PDFDoc=>'C:\docs\pdf', 
+            PDFPages=>"2 6-8 ",
+            PDFDebug=>1);
+
+This really a directive and not a true variable. It is used to debug the setting of variables in a PDF::Extract method call.
+PDFDebug as used above will print:-
+
+ These variables are to be set
+	PDFDoc="C:\docs\pdf/"
+	PDFPages="2 6-8 "
+	PDFDebug="1"
+ These variables have been set
+	PDFCache="C:/myCache"
+	PDFFilename="2_6..8_.pdf"
+	PDFPagesFound=""
+	PDFDoc=""
+    PDFPages="2, 6, 7, 8"
+	PDFPageCount=""
+	PDFExtract=""
+	PDFError="PDF document "" not found at C:/Perl/site/lib/PDF/Extract.pm line 467"
+
 =cut
 
 
@@ -368,7 +451,26 @@ sub setEnv {
     my (undef,  %PDF)=@_;
     my $requestedPages=0;
     $vars{"PDFError"}="";
-    # Initialize variables for reuse
+    if ($PDF{"PDFDebug"} ) {
+        print "These variables are to be set\n";
+        foreach my $key (keys %PDF) {
+            print "\t$key=\"$PDF{$key}\"\n";
+        } 
+    }
+     if ($PDF{"PDFErrorPage"} ) {
+        $vars{"PDFErrorPage"}="";
+         if ( -f $PDF{"PDFErrorPage"} ) {
+	        if (open FILE, $PDF{"PDFErrorPage"} ) {
+				$vars{"PDFErrorFile"} = join('', <FILE>);
+				close FILE;
+		        $vars{"PDFErrorPage"}=$PDF{ "PDFErrorPage"};
+		    } else {
+		        &error( "Can't open PDF Error page template file $PDF{\"PDFErrorPage\"} to read\n",__FILE__,__LINE__);	    
+		    }
+		} else {
+            &error("PDF Error page template file \"$PDF{PDFErrorPage}\" not found",__FILE__,__LINE__);
+		}
+    } 
     if ($PDF{ "PDFDoc" } ) {
         $vars{"PDFDoc"}="";
         $vars{"PDFPageCount"}=$vars{"PDFPagesFound"}=$vars{"PDFExtract"}="";
@@ -377,14 +479,18 @@ sub setEnv {
         %pageObject=();
 
         $filename=$1 if  $PDF{"PDFDoc"}=~/([^\\\/]+)\.pdf$/i;
-        return  &error(" PDF document \"$filename\" not found",__FILE__,__LINE__) unless -f $PDF{"PDFDoc"};
-	    $\="\r";
-	    return &error( "Can't open $PDF{\"PDFDoc\"} to read\n",__FILE__,__LINE__) unless  open FILE, $PDF{"PDFDoc"};
-		binmode FILE;
-		$pdfFile = join('', <FILE>);
-		close FILE;
-        $vars{"PDFDoc"}=$PDF{"PDFDoc"};
-		
+        if ( -f $PDF{"PDFDoc"} ) {
+	        if (open FILE, $PDF{"PDFDoc"} ) {
+				binmode FILE;
+				$pdfFile = join('', <FILE>);
+				close FILE;
+		        $vars{"PDFDoc"}=$PDF{"PDFDoc"};
+		    } else {
+		        &error( "Can't open PDF document  $PDF{\"PDFDoc\"} to read\n",__FILE__,__LINE__);	    
+		    }
+		} else {
+            &error(" PDF document \"$filename\" not found",__FILE__,__LINE__);
+		}
     } 
     if ($PDF{ "PDFPages" } ) {
         $vars{ "PDFPages"}="";
@@ -393,8 +499,7 @@ sub setEnv {
         @object=@obj=@pages=(); 
         %getPages=%pageObject=();
 
-        @PDFPages=$PDF{ "PDFPages" };
-		$pages=join " ", @PDFPages; 
+		$pages=$PDF{ "PDFPages" };
 		my $pageError=$pages;
 		$pages=~s/\.\./-/g;
 		$pages=~s/\.//g;
@@ -408,26 +513,33 @@ sub setEnv {
 	        $getPages{int $page}=1;
 	        $requestedPages++;
 	    }
-	    return &error("Can't get PDF Pages. No page numbers were set with '$pages' ",__FILE__,__LINE__) unless $requestedPages;
-	    $pages="";
-	    foreach my $page ( sort  keys %getPages) { 
-	#        $fileNumber.="_$page";
-	        $pages.="$page, ";
-	    }
-	    $pages=~s/, $//;
-	    $vars{ "PDFPages"}=$pages;
+	    if ( $requestedPages ) {
+		    $pages="";
+		    foreach my $page ( sort  keys %getPages) { 
+		        $pages.="$page, ";
+		    }
+		    $pages=~s/, $//;
+		    $vars{ "PDFPages"}=$pages;
+		} else {
+		    &error("Can't get PDF Pages. No page numbers were set with '$pages' ",__FILE__,__LINE__);
+		}
 	 }
 	 if ($PDF{ "PDFCache"} ) {
         $vars{"PDFCache"}=dir($PDF{ "PDFCache"});
 	 }
-	 if ($PDF{"PDFErrorPage"} ) {
-        $vars{"PDFErrorPage"}="";
-        return  &error(" PDF Error page template file \"$PDF{PDFErrorPage}\" not found",__FILE__,__LINE__) unless -f $PDF{ "PDFErrorPage"};
-	    return &error( "Can't open $PDF{PDFErrorPage} to read\n",__FILE__,__LINE__) unless  open FILE, $PDF{ "PDFErrorPage"};
-		$vars{"PDFErrorFile"} = join('', <FILE>);
-		close FILE;
-        $vars{"PDFErrorPage"}=$PDF{ "PDFErrorPage"};
-    } 
+	 if ( defined $PDF{ "PDFSaveAs" } ) {   # we also want to be able to set PDFSaveAs to nothing ("")       
+        $vars{"PDFSaveAs"} = $PDF{"PDFSaveAs"};
+        $vars{"PDFSaveAs"}=~s/\.pdf$//i;    # just want the name, not the path and not the .pdf tag
+        $vars{"PDFSaveAs"}=~s/^.*[\/\\]//;
+     }
+    $vars{"PDFFilename"}=$vars{"PDFSaveAs"} ? $vars{"PDFSaveAs"}.".pdf" : "$filename$fileNumber.pdf";
+
+    if ( $PDF{"PDFDebug"} ) {
+        print "These variables have been set\n";
+        foreach my $key (keys %vars) {
+            print "\t$key=\"$vars{$key}\"\n";
+        } 
+    }
 }
 
 sub dir {
@@ -440,14 +552,14 @@ sub dir {
 		mkdir $dir, 0x777 unless -d $dir;
 		#   print "$dir\n";
 	}
-	$path=~s/\//\\/g;
+	$path=~s/\//\\/g if $ENV{"OS"}=~/Windows/i;
 	return &error("This Cache path \"$path\" can't be created",__FILE__,__LINE__) 
 	    unless -d $path;
 	$path;
 }
 
 sub redirect {
-	exit print "Content-Type: text/html\n\n<META HTTP-EQUIV='refresh' content='0;url=$filename.pdf'>";
+	exit print "Content-Type: text/html\n\n<META HTTP-EQUIV='refresh' content='0;url=$vars{'PDFFilename'}.pdf'>";
 }
 
 sub getDoc {
@@ -463,8 +575,8 @@ sub getDoc {
 
 sub savePdfDoc {
 	return "" if $vars{"PDFError"};
-	return &error("Can't open $vars{'PDFCache'}/$filename$fileNumber.pdf",__FILE__,__LINE__) 
-	    unless open FILE, ">$vars{'PDFCache'}/$filename$fileNumber.pdf";
+	return &error("Can't open $vars{'PDFCache'}/$vars{'PDFFilename'}",__FILE__,__LINE__) 
+	    unless open FILE, ">$vars{'PDFCache'}/$vars{'PDFFilename'}";
 	binmode FILE;
 	print FILE $vars{"PDFExtract"};
 	close FILE;
@@ -475,11 +587,11 @@ sub uploadPDFDoc {
     my $len=length $vars{"PDFExtract"};
     return &servError("PDF output is null, No output",__FILE__,__LINE__) unless $len;
     print <<EOF;
-Content-Disposition: inline; filename=$filename$fileNumber.pdf
-Content-Length: $len
-Content-Type: application/pdf
-
-$vars{"PDFExtract"}
+Content-Disposition: inline; filename=$vars{"PDFFilename"}\r
+Content-Length: $len\r
+Content-Type: application/pdf\r
+\r
+$vars{"PDFExtract"}\r
 EOF
 }
 
@@ -512,33 +624,33 @@ sub getRoot {
     my $val=$1 if $pdf=~/(trailer\s*<<.*?>>\s*)/s;
     $Root=int $1 if $val=~/\/Root (\d+) 0 R/s;    
     $val=~s/\/Size \d+/\/Size __Size__/s;   # Size will change so put a place holder for new size
-    $val=~s/\/Prev.*?$CRLF//s;                      # delete Prev reference if its there
+    $val=~s/\/Prev.*?$CRLF//s;                  # delete Prev reference if its there
     &getObj($1, $2 ) if $val=~/\/Info (\d+) (\d+) R/s;
     &getObj( $encryptedPdf=$1, $2 ) if $val=~/\/Encrypt (\d+) (\d+) R/s;
     $trailerObject=$val;
-    $val=$1 if $pdf=~/\s($Root 0 obj.*?endobj\s+)/s;
+    $val=$1 if $pdf=~/\D($Root 0 obj.*?endobj\s+)/s;
     $CatalogPages=int $1 if $val=~/\/Pages (\d+) 0 R\s+/s;   
-    $val="$Root 0 obj\r<< \r/Type /Catalog \r/Pages $CatalogPages 0 R \r>> \rendobj\r";
-    $pdf=~s/(\s)$Root 0 obj.*?endobj\s+/$1$val/s; 
+    $val="$Root 0 obj\n<<\n/Type /Catalog\n/Pages $CatalogPages 0 R\n>>\nendobj\n";# changed \r to \n for unixish systems by Alberto Accomazzi
+    $pdf=~s/(\D)$Root 0 obj.*?endobj\s+/$1$val/s; 
 }
 
 sub getObj {
 	return "" if $vars{"PDFError"};
     my($obj,$instnum)=@_;
     unless ($obj[$obj] ) {
-         if ($pdf=~/\s($obj $instnum obj.*?endobj\s)/s ) {
+         if ($pdf=~/\D($obj $instnum obj.*?endobj\s)/s ) {
             $object = $1;
 #	        return "" if $object=~/\/GoToR/; # Don't want these link objects
             $obj[$obj]++;
 	        $object[$obj]=$object;
             $instnum[$obj]=$instnum;
             
-	        $object[$obj]=~s/(\/Dest \[ )(\d+)( \d.*?\r)/&uri($1,$2,$3)/es; # Convert page dest to uri if not present
+	        $object[$obj]=~s/(\/Dest \[ )(\d+)( \d.*?)/&uri($1,$2,$3)/es; # Convert page dest to uri if not present
 	        $object[$obj]=~s/(\d+) (\d+) R/&getObj($1, $2 )/ges;
 #	        $object[$obj]=~s/(\/Dest \[ \d+)==/$1 0/s; # Don't follow this path
 	        $object[$obj]=~s/\/Annots \[\s+\]\s+//s; # Delete empty Annots array
 	    } else {
-	        &error("Can't find object $obj $instnum obj",__FILE__,__LINE__);
+	        &error("Can't find object $obj $instnum obj  ",__FILE__,__LINE__);
 	    }
     }
     "$obj 0 R";
@@ -566,8 +678,8 @@ sub getPages {
             $found.=$f;
             $count+=$c;
         }
-        $pdf=~s/(\s$obj $instnum obj.*?\/Kids \[).*?\]/$1 $found\]/s;
-        $pdf=~s/(\s$obj $instnum obj.*?\/Count )\d+/$1$count/s;
+        $pdf=~s/(\D$obj $instnum obj.*?\/Kids \[).*?\]/$1 $found\]/s;
+        $pdf=~s/(\D$obj $instnum obj.*?\/Count )\d+/$1$count/s;
         $found="$obj $instnum R " if $found;
     } else {
         $pageObject{$obj}=push @pages, $obj; # create a hash of all pages
@@ -586,12 +698,15 @@ sub makePdfDoc {
 	return &error("$vars{PDFDoc} is not a PDF file \n$pdf",__FILE__,__LINE__) 
 	    unless $pdf=~s/^(.*?)($CRLF+)/$2/;
 	$vars{"PDFExtract"}=$1.$2;
-	$vars{"PDFExtract"}.=$1.$2 while( $pdf=~s/^\s+(\%.*?)($CRLF+)/$2/); #include comment lines if any
-	my $xref="xxxxxxxxxx 65535 f\r\f";
+	$vars{"PDFExtract"}.=$1.$2 
+	    while( $pdf=~s/^\s+(\%.*?)($CRLF+)/$2/); #include comment lines if any
+	my $xref="xxxxxxxxxx 65535 f\015\012";
 	my $objCount=1;
 	for( ;$objCount<@object;$objCount++) {
 	    if ($object[$objCount]) {
-	        $xref.=sprintf("%0.10d %0.5d n\015\012",length $vars{"PDFExtract"}, $instnum[$objCount] );
+	        $xref.=sprintf("%0.10d %0.5d n\015\012",
+			       length $vars{"PDFExtract"}, 
+			       $instnum[$objCount] );
 	        $vars{"PDFExtract"}.=$object[$objCount];
 	    } else {
 	        $xref.="xxxxxxxxxx 00001 f\015\012"; 
@@ -603,9 +718,9 @@ sub makePdfDoc {
 	    if $objCount==1;
 	$xref=~s/xxxxxxxxxx/0000000000/s;
 	my $startXref=length $vars{"PDFExtract"};
-	$vars{"PDFExtract"}.="\rxref\r0 $objCount \r$xref";
+	$vars{"PDFExtract"}.="xref\n0 $objCount\n$xref";        # changed \r to \n for unixish systems by Alberto Accomazzi
 	$trailerObject=~s/__Size__/$objCount/s;
-	$vars{"PDFExtract"}.="$trailerObject\rstartxref\r$startXref\r\%\%EOF\r";
+	$vars{"PDFExtract"}.="$trailerObject\nstartxref\n$startXref\n\%\%EOF\n";        # changed \r to \n for unixish systems by Alberto Accomazzi
 }
 
 =head1 AUTHOR
@@ -614,9 +729,15 @@ Noel Sharrock E<lt>mailto:nsharrok@lgmedia.com.auE<gt>
 
 PDF::Extract's home page http://www.lgmedia.com.au/PDF/Extract.asp
 
+Forum for users and developers http://www.lgmedia.com.au/PDF/Forum
+
 =head1 SUPPORT
 
-Much thanks to Lyman Byrd for his welcome programming suggestions and editorial comments on the POD.
+Much thanks to:-
+
+ Lyman Byrd for his welcome programming suggestions and editorial comments on the POD.
+ Michael Cox for his suggestion of PDFSaveAs and for the time he spent in testing the module.
+ Alberto Accomazzi for sharing his time and his knowledge of Unixish PDF voodoo magick.
 
 =head1 COPYRIGHT
 
